<h3>Download</h3>
<p>Current version: <b>{{ version }}</b></p>
<p>Get Quantities from the <a href="http://pypi.python.org/pypi/quantities">
Python Package Index</a>

<h3>Questions? Suggestions? Contributions?</h3>

<p>Visit the
  <a href="http://github.com/python-quantities/python-quantities">Quantities
  project page at github</a>
</p>

