"""
"""

from ._utils import _cd
from ..unitquantity import UnitConstant


hertz_inverse_meter_relationship = UnitConstant(
    'hertz_inverse_meter_relationship',
    _cd('hertz-inverse meter relationship')
)
hertz_joule_relationship = UnitConstant(
    'hertz_joule_relationship',
    _cd('hertz-joule relationship')
)
hertz_kelvin_relationship = UnitConstant(
    'hertz_kelvin_relationship',
    _cd('hertz-kelvin relationship')
)
hertz_kilogram_relationship = UnitConstant(
    'hertz_kilogram_relationship',
    _cd('hertz-kilogram relationship')
)
inverse_meter_hertz_relationship = UnitConstant(
    'inverse_meter_hertz_relationship',
    _cd('inverse meter-hertz relationship')
)
inverse_meter_joule_relationship = UnitConstant(
    'inverse_meter_joule_relationship',
    _cd('inverse meter-joule relationship')
)
inverse_meter_kelvin_relationship = UnitConstant(
    'inverse_meter_kelvin_relationship',
    _cd('inverse meter-kelvin relationship')
)
inverse_meter_kilogram_relationship = UnitConstant(
    'inverse_meter_kilogram_relationship',
    _cd('inverse meter-kilogram relationship')
)
joule_hertz_relationship = UnitConstant(
    'joule_hertz_relationship',
    _cd('joule-hertz relationship')
)
joule_inverse_meter_relationship = UnitConstant(
    'joule_inverse_meter_relationship',
    _cd('joule-inverse meter relationship')
)
joule_kelvin_relationship = UnitConstant(
    'joule_kelvin_relationship',
    _cd('joule-kelvin relationship')
)
joule_kilogram_relationship = UnitConstant(
    'joule_kilogram_relationship',
    _cd('joule-kilogram relationship')
)
kelvin_hertz_relationship = UnitConstant(
    'kelvin_hertz_relationship',
    _cd('kelvin-hertz relationship')
)
kelvin_inverse_meter_relationship = UnitConstant(
    'kelvin_inverse_meter_relationship',
    _cd('kelvin-inverse meter relationship')
)
kelvin_joule_relationship = UnitConstant(
    'kelvin_joule_relationship',
    _cd('kelvin-joule relationship')
)
kelvin_kilogram_relationship = UnitConstant(
    'kelvin_kilogram_relationship',
    _cd('kelvin-kilogram relationship')
)
kilogram_hertz_relationship = UnitConstant(
    'kilogram_hertz_relationship',
    _cd('kilogram-hertz relationship')
)
kilogram_inverse_meter_relationship = UnitConstant(
    'kilogram_inverse_meter_relationship',
    _cd('kilogram-inverse meter relationship')
)
kilogram_joule_relationship = UnitConstant(
    'kilogram_joule_relationship',
    _cd('kilogram-joule relationship')
)
kilogram_kelvin_relationship = UnitConstant(
    'kilogram_kelvin_relationship',
    _cd('kilogram-kelvin relationship')
)

del UnitConstant, _cd
